@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '1.8';
+    return '1.9.7';
   }
 
   function GetHelp()
