@@ -28,6 +28,11 @@ if ($this->GetPreference('block_title','') != '') {
 } else {
     $description_block = '';
 }
+if ($this->GetPreference('canonical_block_title','') != '') {
+    $canonical_block = str_replace(' ','_',$this->GetPreference('canonical_block_title',''));
+} else {
+    $canonical_block = '';
+}
 if ($this->GetPreference('html_title','en') != '') {
     $lang_block = $this->GetPreference('html_title','en');
 } else {
@@ -43,6 +48,8 @@ if ($this->GetPreference('content_var_title','') != '') {
 
 
 $pageSmarty = $this->GetPreference('page_smarty','');
+$ogimageSmarty = $this->GetPreference('ogimage_smarty_title','');
+$ogtypeSmarty = $this->GetPreference('ogtype_smarty_title','');
 
 
 ///// PAGE SPECIFIC METADATA /////
@@ -161,17 +168,19 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
     $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-    //$desc = htmlentities($desc, ENT_COMPAT, 'UTF-8'); //Commented out to solve unicode display problems
-    //$desc = utf8_encode(html_entity_decode($desc)); //Commented out to solve unicode display problems
 } elseif ($this->GetPreference('auto_title','1') == 1 && $curcontent->GetPropertyValue($description_block) == '') {
     if ($contentVar != '') {
         foreach ($contentVar as $key => $countVar2) {
-            $countVars2[] = $smarty->get_template_vars($countVar2);
+			$content_value = $smarty->get_template_vars($countVar2);
+			if($content_value != "") {
+				$countVars2[] = $content_value;
+			}
+			$content_value = NULL;
         }
-        $countVars2 = join(' ', $countVars2);
+        $countVars2 = preg_replace('!\s+!', ' ', trim(strip_tags(join(' ', $countVars2))));
     }
-    $contentBasic2 = $curcontent->GetPropertyValue('content_en');
-    $desc = $contentBasic2 . $countVars2;
+    $contentBasic = $curcontent->GetPropertyValue('content_en');
+    $desc = $countVars2 . ' ' . $contentBasic;
     $desc = preg_replace('/[\n\r]/',' ',$desc);
     $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
     $desc = trim($desc);
@@ -179,27 +188,27 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
     $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-    //$desc = htmlentities($desc, ENT_COMPAT, 'UTF-8'); //Commented out to solve unicode display problems
-    //$desc = utf8_encode(html_entity_decode($desc)); //Commented out to solve unicode display problems
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } elseif ($this->GetPreference('auto_title','1') == 1) {
     if ($contentVar != '') {
         foreach ($contentVar as $key => $countVar2) {
-            $countVars2[] = $smarty->get_template_vars($countVar2);
+			$content_value = $smarty->get_template_vars($countVar2);
+			if($content_value != "") {
+				$countVars2[] = $content_value;
+			}
+			$content_value = NULL;
         }
-        $countVars2 = join(' ', $countVars2);
+        $countVars2 = preg_replace('!\s+!', ' ', trim(strip_tags(join(' ', $countVars2))));
     }
-    $contentBasic2 = $curcontent->GetPropertyValue('content_en');
-    $desc = $contentBasic2 . $countVars2;
+    $contentBasic = $curcontent->GetPropertyValue('content_en');
+    $desc = $countVars2 . ' ' . $contentBasic;
     $desc = preg_replace('/[\n\r]/',' ',$desc);
     $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
     $desc = str_replace('><','> <',$desc);
     $desc = strip_tags(str_replace('"','',$desc));
     $desc = preg_replace('/{.*}/','',$desc);
     $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
-    //$desc = htmlentities($desc, ENT_COMPAT, 'UTF-8'); //Commented out to solve unicode display problems
-    //$desc = utf8_encode(html_entity_decode($desc)); //Commented out to solve unicode display problems
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } else {
@@ -207,6 +216,13 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
 }
 
 
+///// Canonical link /////
+
+if ($curcontent->GetPropertyValue($canonical_block) != '') {
+    $canonical = $curcontent->GetPropertyValue($canonical_block);
+}
+
+
 ///// XML LANGUAGE /////
 $xmlLang = $this->GetPreference('html_title','en');
 $lang_count = '0';
@@ -240,6 +256,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('dublin_title', $this->GetPreference('dublin_title','0'));
    $this->smarty->assign('opengraph_title', $this->GetPreference('opengraph_title','0'));
    $this->smarty->assign('tweetme_title', $this->GetPreference('tweetme_title','0'));
+   $this->smarty->assign('touchicon_root_title', $this->GetPreference('touchicon_root_title','0'));
    $this->smarty->assign('touchicon_title', $this->GetPreference('touchicon_title','0'));
    $this->smarty->assign('fullscreen_title', $this->GetPreference('fullscreen_title','-1'));
    $this->smarty->assign('statusbar_title', $this->GetPreference('statusbar_title','-1'));
@@ -250,6 +267,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('minimum_title', $this->GetPreference('minimum_title',''));
    $this->smarty->assign('maximum_title', $this->GetPreference('maximum_title',''));
    $this->smarty->assign('scalable_title', $this->GetPreference('scalable_title','-1'));
+   $this->smarty->assign('robots_title', $this->GetPreference('robots_title','-1'));
    $this->smarty->assign('publisher_title', $this->GetPreference('publisher_title',''));
    $this->smarty->assign('contributor_title', $this->GetPreference('contributor_title',''));
    $this->smarty->assign('relation_title', $this->GetPreference('relation_title',''));
@@ -264,13 +282,19 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('latitude_title', $this->GetPreference('latitude_title',''));
    $this->smarty->assign('longitude_title', $this->GetPreference('longitude_title',''));
    $this->smarty->assign('ogtype_title', $this->GetPreference('ogtype_title',''));
+   $this->smarty->assign('ogtype_smarty_title', $smarty->get_template_vars($ogtypeSmarty));
    $this->smarty->assign('ogimage_title', $this->GetPreference('ogimage_title','0'));
+   $this->smarty->assign('ogimage_smarty_title', $smarty->get_template_vars($ogimageSmarty));
+   $this->smarty->assign('favicon_root_title', $this->GetPreference('favicon_root_title','0'));
    $this->smarty->assign('favicon_title', $this->GetPreference('favicon_title','0'));
    $this->smarty->assign('favsize_title', $this->GetPreference('favsize_title',''));
    $this->smarty->assign('fbpage_title', $this->GetPreference('fbpage_title',''));
    $this->smarty->assign('fbadmin_title', $this->GetPreference('fbadmin_title',''));
    $this->smarty->assign('fbapp_title', $this->GetPreference('fbapp_title',''));
+   $this->smarty->assign('twittersite_title', $this->GetPreference('twittersite_title',''));
+   $this->smarty->assign('googleplus_title', $this->GetPreference('googleplus_title',''));
    $this->smarty->assign('analyticstype_title', $this->GetPreference('analyticstype_title','-1'));
+   $this->smarty->assign('analytics_support', $this->GetPreference('analytics_support','0'));
    $this->smarty->assign('propertyid_title', $this->GetPreference('propertyid_title',''));
    $this->smarty->assign('webmasterid_title', $this->GetPreference('webmasterid_title',''));
    $this->smarty->assign('pretty_title', $this->GetPreference('pretty_title','0'));
@@ -314,6 +338,7 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('meta_block', $curcontent->GetPropertyValue($meta_block));
    $this->smarty->assign('description_block', $curcontent->GetPropertyValue($description_block));
    $this->smarty->assign('page_description', $desc);
+   $this->smarty->assign('canonical', $canonical);
    $this->smarty->assign('contentText', $countVars);
    $this->smarty->assign('pageMeta', $pageMeta);
 }
