@@ -11,6 +11,7 @@ $this->SetPreference('delimiter_title', $params['delimiter_title']);
 $this->SetPreference('meta_block_title', $params['meta_block_title']);
 $this->SetPreference('content_var_title', $params['content_var_title']);
 $this->SetPreference('block_title', $params['block_title']);
+$this->SetPreference('canonical_block_title', $params['canonical_block_title']);
 $this->SetPreference('auto_title',
 		     (isset($params['auto_title'])?'1':'0'));
 $this->SetPreference('length_title', $params['length_title']);
@@ -26,6 +27,7 @@ $this->SetPreference('opengraph_title',
 $this->SetPreference('tweetme_title',
 		     (isset($params['tweetme_title'])?'1':'0'));
 
+$this->SetPreference('touchicon_root_title', $params['touchicon_root_title']);
 $this->SetPreference('touchicon_title', $params['touchicon_title']);
 $this->SetPreference('fullscreen_title', $params['fullscreen_title']);
 $this->SetPreference('statusbar_title', $params['statusbar_title']);
@@ -37,6 +39,7 @@ $this->SetPreference('minimum_title', $params['minimum_title']);
 $this->SetPreference('maximum_title', $params['maximum_title']);
 $this->SetPreference('scalable_title', $params['scalable_title']);
 
+$this->SetPreference('robots_title', $params['robots_title']);
 $this->SetPreference('publisher_title', $params['publisher_title']);
 $this->SetPreference('contributor_title', $params['contributor_title']);
 $this->SetPreference('relation_title', $params['relation_title']);
@@ -51,12 +54,17 @@ $this->SetPreference('country_title', $params['country_title']);
 $this->SetPreference('latitude_title', $params['latitude_title']);
 $this->SetPreference('longitude_title', $params['longitude_title']);
 $this->SetPreference('ogtype_title', $params['ogtype_title']);
+$this->SetPreference('ogtype_smarty_title', $params['ogtype_smarty_title']);
 $this->SetPreference('ogimage_title', $params['ogimage_title']);
+$this->SetPreference('ogimage_smarty_title', $params['ogimage_smarty_title']);
+$this->SetPreference('favicon_root_title', $params['favicon_root_title']);
 $this->SetPreference('favicon_title', $params['favicon_title']);
 $this->SetPreference('favsize_title', $params['favsize_title']);
 $this->SetPreference('fbpage_title', $params['fbpage_title']);
 $this->SetPreference('fbadmin_title', $params['fbadmin_title']);
 $this->SetPreference('fbapp_title', $params['fbapp_title']);
+$this->SetPreference('twittersite_title', $params['twittersite_title']);
+$this->SetPreference('googleplus_title', $params['googleplus_title']);
 
 $params = array('tab_message'=> 'prefsupdated', 'active_tab' => 'meta');
 $this->Redirect($id, 'defaultadmin', '', $params);
