@@ -45,7 +45,9 @@ $lang['meta_block_title_help'] = 'This should be the name given to your metadata
 $lang['content_var_title'] = 'Content block variables';
 $lang['content_var_title_help'] = 'A comma seperated list of variables';
 $lang['block_title'] = 'Name of page description content block';
+$lang['canonical_block_title'] = 'Name of canonical content block';
 $lang['block_title_help'] = 'This should be the name given to your page description content block, check module help for more info';
+$lang['canonical_block_title_help'] = 'This should be the name given to your canonical link content block, check module help for more info';
 $lang['length_title'] = 'Number of words to appear in auto description';
 $lang['auto_title'] = 'Automatically generate a page description where none is provided';
 $lang['base_title'] = 'Generate Base Tag';
@@ -111,6 +113,8 @@ $lang['jquery_false'] = 'False';
 $lang['dublin_title'] = 'Generate Dublin Core Meta Tags';
 $lang['opengraph_title'] = 'Generate OpenGraph Meta Tags (e.g. for Facebook Like Button)';
 $lang['tweetme_title'] = 'Generate Tweetme title';
+$lang['touchicon_root_title'] = 'Website Apple touch icon';
+$lang['touchicon_root_title_help'] = 'Select an image from your root directory to be used as the Apple touch icon, should be 120px x 120px .png file';
 $lang['touchicon_title'] = 'Website Apple touch icon';
 $lang['touchicon_title_help'] = 'Select an image from your /uploads/images directory to be used as the Apple touch icon, should be 120px x 120px .png file';
 $lang['drop_select'] = 'Please Select';
@@ -129,6 +133,11 @@ $lang['initial_title'] = 'Viewport initial scale';
 $lang['minimum_title'] = 'Viewport minimum scale, range is from >0 to 10.0';
 $lang['maximum_title'] = 'Viewport maximum scale, range is from >0 to 10.0';
 $lang['scalable_title'] = 'Viewport user scalable';
+$lang['robots_title'] = 'Robots meta tag';
+$lang['robots_default'] = 'index, follow';
+$lang['robots_1'] = 'noindex, follow';
+$lang['robots_2'] = 'index, nofollow';
+$lang['robots_3'] = 'noindex, nofollow';
 $lang['publisher_title'] = 'Site publisher';
 $lang['contributor_title'] = 'Site contributor';
 $lang['relation_title'] = 'Related website';
@@ -144,9 +153,15 @@ $lang['latitude_title'] = 'Latitude of your entity';
 $lang['longitude_title'] = 'Longitude of your entity';
 $lang['ogtitle_title'] = 'OpenGraph page title';
 $lang['ogtype_title'] = 'OpenGraph default page type';
+$lang['ogtype_smarty_title'] = 'Smarty variable for page specific OpenGraph type';
+$lang['ogtype_smarty_title_help'] = 'Useful in News and Blog articles where a more specific type may be preferred.';
 $lang['ogname_title'] = 'OpenGraph site name';
 $lang['ogimage_title'] = 'OpenGraph default image';
-$lang['ogimage_title_help'] = 'Select an image from your /uploads/images directory to be used as the default for OpenGraph pages';
+$lang['ogimage_title_help'] = 'Select an image from your /uploads/images directory to be used as the default for OpenGraph pages (200px x 200px)';
+$lang['ogimage_smarty_title'] = 'Smarty variable for page specific OpenGraph image';
+$lang['ogimage_smarty_title_help'] = 'Useful in News and Blog articles where a more specific image may be preferred.';
+$lang['favicon_root_title'] = 'Website favicon';
+$lang['favicon_root_title_help'] = 'Select an image from your root directory to be used as the site favicon, should be an .ico file';
 $lang['favicon_title'] = 'Website favicon';
 $lang['favicon_title_help'] = 'Select an image from your /uploads/images directory to be used as the site favicon, should be an .ico file';
 $lang['favsize_title'] = 'Website favicon sizes';
@@ -154,6 +169,10 @@ $lang['favsize_title_help'] = 'Select your icon sizes if using multi-image ico f
 $lang['fbpage_title'] = 'Facebook page ID';
 $lang['fbadmin_title'] = 'Facebook site administrators ID';
 $lang['fbapp_title'] = 'Facebook application ID';
+$lang['twittersite_title'] = 'Twitter ID';
+$lang['twittersite_title_help'] = 'Your @ name. i.e @cmsms';
+$lang['googleplus_title'] = 'Google Plus profile URL';
+$lang['googleplus_title_help'] = 'Your Google Plus profile page URL. i.e https://plus.google.com/101806562165793532909/posts';
 $lang['key_number'] = 'Number of keywords';
 $lang['key_length'] = 'Length of keywords';
 $lang['key_length_help'] = 'Minimum character length before becoming a keyword';
@@ -164,12 +183,12 @@ $lang['keyskip_title'] = 'Keyword STOP words';
 $lang['key_stop_help'] = 'Words not to include as keywords, comma seperated list';
 $lang['xml_title'] = 'Create an XML Google Sitemap';
 $lang['push_title'] = 'Automatically push the sitemap to Google after content changes';
-$lang['robots_title'] = 'Create a robots.txt file';
 $lang['analytics_type'] = 'Anlytics type';
 $lang['analytics_select'] = 'Please select one';
 $lang['analytics_single'] = 'A single domain';
 $lang['analytics_sub'] = 'One domain with multiple subdomains';
 $lang['analytics_multiple'] = 'Multiple top-level domains';
+$lang['analytics_support'] = 'Display Advertiser Support';
 $lang['propertyid_title'] = 'Web Property ID (ie UA-XXXXXXXX-1)';
 $lang['webmasterid_title'] = 'Webmaster meta verification key';
 $lang['pretty_title'] = 'Are pretty URLs enabled?';
@@ -218,7 +237,13 @@ $lang['changelog'] = '<ul>
 <li>Version 1.7.8 6 November 2012. Fixed issue where canonical link for news articles showed default detail page URL rather than news story URL.</li>
 <li>Version 1.7.9 26 November 2012. Added the ability to use CMSMS page specific metadata field instead of adding content block to your templates.</li>
 <li>Version 1.7.9.1 27 November 2012. Stopped default holding meta text appearing.</li>
-<li>Version 1.8 18 December 2012. Canonical link bug fix.</li></ul>';
+<li>Version 1.8 18 December 2012. Canonical link bug fix.</li>
+<li>Version 1.9.1 4 February 2013. Minor bug fix.</li>
+<li>Version 1.9.2 5 February 2013. Template update and addition of OpenGraph image smarty call to specify non default OpenGraph image, suggested by Gregor.</li>
+<li>Version 1.9.3 25 February 2013. Added the option to specify canonical links per page using in content block, also added a Display Advertiser Support option to the analytics tab.</li>
+<li>Version 1.9.4 21 March 2013. Added the options to choose Apple Touch and Fav icons from the website root directory.</li>
+<li>Version 1.9.6 11 April 2013. Added the option to choose robots meta and Twitter card and Google+ profile page links.</li>
+<li>Version 1.9.7 18 April 2013. Content block variables now appear in order in the description tag, appended by the content of the default Content block by default.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
@@ -227,7 +252,7 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 <p>Firstly you need to remove the standard &#123;metadata} call, this is not compatible with Meta Max and may cause problems. You may also need to remove your <DOCTYPE>, opening <html> tag and <head> tags depending on which parameters you have enabled.</p>
 <p>Just add &#123;MetaMax} to the top or head of each template.</p>
 <p>If you are using the auto description option you will need to add &#123;capture}&#123;content block=\'Page Description\' oneline=\'true\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'page description content block\' input field, which in this example is Page Description.</p>
-<p>If you want page specific metadata simply add &#123;capture}&#123;content block=\'Metadata\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'metadata content block\' input field, which in this example is Metadata.</p>
+<p>If you want page specific metadata simply add &#123;capture}&#123;content block=\'Metadata\' wysiwyg=\'false\'}&#123;/capture} to your templates and reference this content blocks name in the \'metadata content block\' input field, which in this example is Metadata. Similar setup for the page description and canonical link options. Canonical links need the full URL, i.e http://www.cmsmadesimple.org</p>
 <p>The Analytics search options are only required if you are using pretty URL\'s in conjunction with the search module\'s POST method otherwise simply adding the default cntnt01searchinput into your Analytics setup will track site search queries.</p>
 <p>There are more examples and instructions available at https://sites.google.com/site/metamaxwiki/ please feel free to contribute any examples and findings you have.</p>
 <h3>Support</h3>
